----------------------------
pirt.apps - Simple demo apps 
----------------------------

.. automodule:: pirt.apps

----

.. autoclass:: pirt.apps.spline_by_hand.SplineByHand
    :members:

.. autoclass:: pirt.apps.deform_by_hand.DeformByHand
    :members:
